罗马假日 (豆瓣)
Description: 罗马假日电影简介和剧情介绍,罗马假日影评、图片、预告片、影讯、论坛、在线购票
Keywords: 罗马假日,Roman Holiday,罗马假日影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.52豆瓣电影Top250

# 罗马假日 Roman Holiday (1953)

导演: 威廉·惠勒
编剧: 达尔顿·特朗勃 / 伊安·麦克莱伦·亨特 / 约翰·戴顿
主演: 奥黛丽·赫本 / 格利高里·派克 / 埃迪·艾伯特 / 哈特利·鲍尔 / 哈考特·威廉姆斯 / 玛格丽特·罗林斯 / 托里奥·卡米纳提 / 保罗·卡利尼 / 克劳迪奥·埃尔梅利 / 保拉·布鲁布尼 / 里佐·弗雷多里佐
类型: 剧情 / 喜剧 / 爱情
制片国家/地区: 美国
语言: 英语 / 意大利语 / 德语
上映日期: 1953-08-20(威尼斯电影节) / 1953-09-02(美国)
片长: 118分钟
又名: 金枝玉叶(港) / 罗马假期(台) / 罗马的假日
IMDb: tt0046250
豆瓣评分
引用
9.1
908971人评价
5星
60.4%
4星
32.8%
3星
6.4%
2星
0.3%
1星
0.1%
好于 99% 爱情片
好于 99% 喜剧片
想看 看过
评价:
推荐

## 罗马假日的剧情简介 · · · · · ·

欧洲某国的安妮公主（奥黛丽·赫本 Audrey Hepburn 饰）到访罗马，国务烦身，但她又厌倦繁文缛节。一天晚上，身心俱疲的她偷偷来到民间欣赏夜景，巧遇报社记者乔（格里高利·派克 Gregory Peck 饰）。二人把手同游，相当快乐。公主更是到乔的家中作客并在那过夜。
不料乔无意中发现了公主的真实身份，他决定炮制一个独家新闻，于是乔和朋友、摄影师欧文（埃迪·艾伯特 Eddie Albert 饰）一起带公主同游罗马，并且偷拍了公主的很多生活照。然而，在接下来与公主的相处中，乔不知不觉恋上了公主。为了保护公主的形象，乔只能忍痛抛弃功成名就的良机，将照片送予了公主。
安妮公主在经历了罗马一日假期后，反而体验了自己对国家的责任，毅然返回了大使馆，为了本身的责任而果断抛弃了爱情。 ©豆瓣

## 罗马假日的演职员 · · · · · · ( 全部 40 )

- 威廉·惠勒 导演
- 奥黛丽·赫本 饰 Princess Ann
- 格利高里·派克 饰 Joe Bradley
- 埃迪·艾伯特 饰 Irving Radovich
- 哈特利·鲍尔 饰 Mr. Hennessy
- 哈考特·威廉姆斯 饰 Ambassador

## 罗马假日的视频和图片 ······ ( 预告片1 | 添加视频评论 | 图片976 · 添加 )

## 罗马假日的获奖情况 · · · · · · ( 全部 )

- 第26届奥斯卡金像奖
- 最佳影片(提名)
- 威廉·惠勒

- 第14届威尼斯电影节
- 主竞赛单元 金狮奖 (提名)
- 威廉·惠勒

- 第11届金球奖
- 电影类 剧情片最佳女主角
- 奥黛丽·赫本

## 喜欢这部电影的人也喜欢 · · · · · ·

  泰坦尼克号

  魂断蓝桥

  爱在黎明破晓前

  乱世佳人

  恋恋笔记本

  重庆森林

  甜蜜蜜

  天使爱美丽

  傲慢与偏见

  花样年华

我要写短评

## 罗马假日的短评 · · · · · · ( 全部 169160 条 )

热门 / 最新 / 好友

### 2857 有用 Ocap 看过 2015-08-30 10:28:13

从他背对着走，到不自然的转身，观众和他一样，都在奢望些什么。最后整个记者会的段落，就像戏剧和现实的静谧对抗，现实赢了，却让戏剧的魅力更大。也许爱情就是，你不知道她会不会出现，但你却能肯定：她也想出现。这就够了。这样的结局不知可以完爆多少现代爱情片。

### 4804 有用 影志 看过 2006-01-08 05:14:19

赫本，无与伦比的美丽。

### 1692 有用 熊阿姨 看过 2005-07-17 14:13:25

没有看过这个的经历会显得自己太无知老土，看过了，觉得真是金童玉女啊，真是令人向往的爱情啊！真是......尽管看完了该无知还无知，老土的也没变洋气，毕竟主人公那长相那气质不是几个整容手术几部电影能成就的。

### 4328 有用 Doublebitch 看过 2010-07-29 11:49:03

离开你 并不是因为不爱你

### 1464 有用 同志亦凡人中文站 看过 2015-07-11 08:26:34

因为罗马，所以经典。因为短暂，所以永恒。顶着锅盖说一句：其实赫本的气质大过演技～

> 更多短评 169160条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 罗马假日的影评 · · · · · · ( 全部 1737 条 )

热门 / 最新 / 好友
夜空的风筝 2008-10-14 12:34:45

## 惊世未了情

罗马假日 赫本与格里高里·派克 转载 他是一个绅士，是世界上最有气质的男人，有着雕塑一般坚毅的轮廓和刚直不阿的个性。他举止优雅，气质谦和，纯净的眼神像个庄严的传教士。他能将笑容演绎得让人心动，柔肠百转而又分寸在握。他是全球数以千万计的女人们的梦中... (展开)
4146 182 391回应 收起
猫熊 2007-03-16 13:31:52

## 购物的隐喻和杜撰的女性消费喜爱度调查

工作休息的时候重温了一下。 这次注意到一个细节。 记者给了公主1000里拉。公主用这钱先在地摊买了一双平跟凉鞋，因为电影前面交待了她原来那双高跟鞋不舒服。然后她去理发店作了新发型。然后是买了一支冰激凌，最后是没钱买鲜花，但是获得摊主赠送一支。 由此可以排列出在女... (展开)
2297 283 231回应 收起
Pandy 2005-08-15 02:36:16

## 天下有罗马,却无那样的假日

美妙年华的公主，短暂逃出皇室的藩篱，在街头喧闹的阳光下放肆真性情，贪婪地享受作为平民的自由，做一回真女孩。这就是尽人皆知的电影《罗马假日》。 奥黛丽-赫本在1993年就已经作古了，天使回到了天堂，从此人世上就再也没有了安妮公主那瞬间乍现的率真和天然。这个世上缺了... (展开)
1501 121 201回应 收起
鳇惑 2008-12-28 21:33:30

## 罗马假日

这篇影评可能有剧透

爱上一个不该爱的人 该如何？ 爱上一个不可能的人 又该如何？ 当相聚时光只有一日 该怎样度过？ 当美好爱情只开一刹 又该怎样挽留？ 花未全开 月未圆 不完美 却有着如斯残缺的美丽 世间的感情莫过于两种：一种是相濡以沫，却厌倦到终老；另一种是相忘于江湖，却怀念到哭泣... (展开)
891 38 88回应 收起
小猴 2006-09-28 20:07:34

## 为什么罗马假日会是经典

五一春假，对于单身的朋友们来说与其去游山玩水，倒不如抽空谈场恋爱来的值得——当然，前提是如果你足够浪漫，相信纯情年代、相信浪漫真情。 1953年出品的黑白电影《罗马假日》，历被人们奉为爱情电影中的经典之作。《罗马假日》的情节简单，却凭借男女主角的成功出... (展开)
451 24 34回应 收起
极简主义 2010-08-25 00:47:00

## 1954年的那枚蝴蝶胸针 （派克和赫本）

他是一个绅士，是世界上最英俊的男人，有着雕塑一般坚毅的轮廓和刚直不阿的个性。他举止优雅，气质谦和，纯净的眼神像个庄严的传教士。他能将笑容演绎得让人心动，柔肠百转而又分寸在握。他是全球数以千万计的女人们的梦中情人，他的生命里有无数俏颜佳丽走过，却没有出现... (展开)
226 20 40回应 收起
悲伤逆流成河 2017-05-23 08:17:10

## 历久不衰的好莱坞爱情轻喜剧之一

作为电影史上爱情文艺片的典范，《罗马假日》情节简单，片中也毫无大制作场面，却是最历久不衰的好莱坞爱情轻喜剧之一。安妮公主作为王位继承人将出访欧洲的各大城市。消息一经传出便引起了极大的轰动。安妮公主欧洲之行的最后一站是罗马，安妮公主很想尽情地饱览一下罗马的优... (展开)
88 9 0回应 收起
美神经 2017-07-31 23:49:18

## 罗马温情一日

这篇影评可能有剧透

《罗马假日》 一部上个世纪五十年代，给人一种明媚的伤感的黑白电影。 一位公主，逃脱繁文缛节，独自游曳于罗马喧闹的街头，邂逅了世俗绅士的他。 我相信每个女孩都渴望像公主那样，在艳阳下和喜欢的人，穿梭于古城的大街小巷，在西班牙广场上吃一个美味的冰淇淋，许愿池边许下... (展开)
78 3 2回应 收起
阿厚 2006-04-29 13:47:21

## 永远的绅士和淑女

永远的绅士派克和永远的淑女赫本都已经辞世，但他们共同缔造的这部爱情片成为电影史上 的绝对经典。印象最深刻的是穷记者和安妮公主都已经心灵互属就亟待一个爆发点了。记者把公主带到罗马的真理之嘴，骗说把手伸进去如讲撒谎就会被狮口吞食。当他伸入再出来时真的是不见了手... (展开)
95 11 20回应 收起

> 更多影评 1737篇

添加新讨论

## 讨论区 · · · · · ·

没看出来赫本有170啊 | 来自青且 | 1 回应 | 2022-11-04 23:08:31
请给出一个这部片子值9分的理由 | 来自小工調 | 35 回应 | 2022-11-04 23:07:15
我现在必须要离开你了，我会走到那个拐角，然后转... | 来自兮沫 |  | 2022-11-04 19:28:17
赫本，我的女神 | 来自遥遥望望 |  | 2022-10-30 09:37:30
我不理解其中的爱情 | 来自明明iF | 3 回应 | 2022-10-27 01:22:13

> 去这部影片的讨论区（全部361条）

## 关于《罗马假日》的问题 · · · · · · ( 全部10个 )

- 摄影师欧文为什么一只在调打火机？ 5人回答
- 喜欢小人的是碧池。公主也可以是碧池，骑着白马的不一定是王子？ 2人回答

> 全部10个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【浪漫爱情轻喜】 (影志)
- 【城市印象】— 跟着电影去旅行 (狷介有乌青)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- 100部爱情电影 经典的回味 (isay)

## 谁在看这部电影 · · · · · ·

- 墨央子
  1分钟前 看过
- 诚明
  2分钟前 看过
- 自由
  3分钟前 看过

1682445人看过 / 344817人想看

订阅罗马假日的评论:
feed: rss 2.0